#ifndef LPC_STRINGS_H_
#define LPC_STRINGS_H_ 1

/* 'where' argument values for trim() */

#define TRIM_LEFT  0x01
#define TRIM_RIGHT 0x02
#define TRIM_BOTH  (TRIM_LEFT|TRIM_RIGHT)

#endif /* LPC_STRINGS_H_ */
